* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
* This automated bisection report was sent to you on the basis *
* that you may be involved with the breaking commit it has *
* found. No manual investigation has been done to verify it, *
* and the root cause of the problem may be somewhere else. *
* Hope this helps! *
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
next/master boot bisection: next-20181220 on tegra124-nyan-big
Summary:
Start: 1efde6eb1819 Add linux-next specific files for 20181220
Details: https://kernelci.org/boot/id/5c1b9ce459b514bfcd0a8184
Plain log:
https://storage.kernelci.org//next/master/next-20181220/arm/tegra_defconfig/lab-collabora/boot-tegra124-nyan-big.txt
HTML log:
https://storage.kernelci.org//next/master/next-20181220/arm/tegra_defconfig/lab-collabora/boot-tegra124-nyan-big.html
Result: 641fb0efbff0 iommu/of: Don't call iommu_ops->add_device directly
Checks:
revert: PASS
verify: PASS
Parameters:
Tree: next
URL: http://git.kernel.org/pub/scm/linux/kernel/git/next/linux-next.git
Branch: master
Target: tegra124-nyan-big
CPU arch: arm
Lab: lab-collabora
Config: tegra_defconfig
Test suite: boot
Breaking commit found:
-------------------------------------------------------------------------------
commit 641fb0efbff063ed57f108c2eb4a4d26dbd5badd
Author: Joerg Roedel <[email protected]>
Date: Wed Dec 5 14:39:45 2018 +0100
iommu/of: Don't call iommu_ops->add_device directly
Make sure to invoke this call-back through the proper
function of the IOMMU-API.
Signed-off-by: Joerg Roedel <[email protected]>
diff --git a/drivers/iommu/of_iommu.c b/drivers/iommu/of_iommu.c
index dbe73456f1a1..d8947b28db2d 100644
--- a/drivers/iommu/of_iommu.c
+++ b/drivers/iommu/of_iommu.c
@@ -222,10 +222,10 @@ const struct iommu_ops *of_iommu_configure(struct device
*dev,
}
/*
* If we have reason to believe the IOMMU driver missed the initial
* add_device callback for dev, replay it to get things in order.
*/
- if (ops && ops->add_device && dev->bus && !device_iommu_mapped(dev))
- err = ops->add_device(dev);
+ if (dev->bus && !device_iommu_mapped(dev))
+ err = iommu_probe_device(dev);
/* Ignore all other errors apart from EPROBE_DEFER */
if (err == -EPROBE_DEFER) {
-------------------------------------------------------------------------------
Git bisection log:
-------------------------------------------------------------------------------
git bisect start
# good: [c5c08bed843c2b2c048c16d1296d7631d7c1620e] virtio: fix test build after
uio.h change
git bisect good c5c08bed843c2b2c048c16d1296d7631d7c1620e
# bad: [1efde6eb181908e1095b4a5db90af0c024016bec] Add linux-next specific files
for 20181220
git bisect bad 1efde6eb181908e1095b4a5db90af0c024016bec
# good: [6580aac4d9913a22e269d7df8db1f9efb8d7fe14] Merge remote-tracking branch
'crypto/master'
git bisect good 6580aac4d9913a22e269d7df8db1f9efb8d7fe14
# bad: [75f962d8fe5279ac9e64f3d411b8e38b84da8d6b] Merge remote-tracking branch
'spi/for-next'
git bisect bad 75f962d8fe5279ac9e64f3d411b8e38b84da8d6b
# good: [d675ba4b9e6ccd782e4db9109cbab708a85b8ff8] Merge tag
'drm-msm-next-2018-12-12' of git://people.freedesktop.org/~robclark/linux into
drm-next
git bisect good d675ba4b9e6ccd782e4db9109cbab708a85b8ff8
# good: [6173f57441f9c05050aad441a2188eaabbfea7a0] Merge remote-tracking branch
'block/for-next'
git bisect good 6173f57441f9c05050aad441a2188eaabbfea7a0
# good: [1531a9f0415ba8ea0f4e31d6f5a1ef059d19dc6d] Merge remote-tracking branch
'regulator/for-next'
git bisect good 1531a9f0415ba8ea0f4e31d6f5a1ef059d19dc6d
# bad: [e2267b2875b0798814d0a76a304318e0c6d60c3e] Merge remote-tracking branch
'vfio/next'
git bisect bad e2267b2875b0798814d0a76a304318e0c6d60c3e
# good: [96ae0a1f40d405f8f0221f4fa8b9b2ef4bbbc01e] Merge remote-tracking branch
'watchdog/master'
git bisect good 96ae0a1f40d405f8f0221f4fa8b9b2ef4bbbc01e
# bad: [d2e1a003af569e912d5f115a3c20b89a19f5caa0] ACPI/IORT: Don't call
iommu_ops->add_device directly
git bisect bad d2e1a003af569e912d5f115a3c20b89a19f5caa0
# good: [9b468f7d9cf1f089b7287865776eb100504681b7] iommu/arm-smmu: Use helper
functions to access dev->iommu_fwspec
git bisect good 9b468f7d9cf1f089b7287865776eb100504681b7
# good: [170ecbd5ff09aa9c8c1025a8563f76e01a24bb50] iommu/of: Use
device_iommu_mapped()
git bisect good 170ecbd5ff09aa9c8c1025a8563f76e01a24bb50
# good: [f884f6ee62604aec60fe1760f94724be192d97c0] dmaengine: sh: rcar-dmac:
Use device_iommu_mapped()
git bisect good f884f6ee62604aec60fe1760f94724be192d97c0
# good: [cc5aed44a3a8e4fca721636cf881a52f8d68a098] iommu: Consolitate
->add/remove_device() calls
git bisect good cc5aed44a3a8e4fca721636cf881a52f8d68a098
# bad: [641fb0efbff063ed57f108c2eb4a4d26dbd5badd] iommu/of: Don't call
iommu_ops->add_device directly
git bisect bad 641fb0efbff063ed57f108c2eb4a4d26dbd5badd
# first bad commit: [641fb0efbff063ed57f108c2eb4a4d26dbd5badd] iommu/of: Don't
call iommu_ops->add_device directly
-------------------------------------------------------------------------------_______________________________________________
iommu mailing list
[email protected]
https://lists.linuxfoundation.org/mailman/listinfo/iommu
@@ -222,10 +222,10 @@ const struct iommu_ops *of_iommu_configure(struct device
/*
* If we have reason to believe the IOMMU driver missed the initial
- * add_device callback for dev, replay it to get things in order.
+ * probe for dev, replay it to get things in order.
*/